/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "chtcode.hh"

CHTCode::CHTCode(wxString &name, int address, int value, bool active) {
    this->name = new wxString(name);
    this->address = address;
    this->value = value;
    this->active = active;
}

CHTCode::CHTCode(const CHTCode &chtcode) {
    name = new wxString(*chtcode.name);
    address = chtcode.address;
    value = chtcode.value;
    active = chtcode.active;
}

CHTCode::~CHTCode() {
    delete name;
}

CHTCode CHTCode::parseCHTData(const char *data) {
    wxString name;
    bool active = true;
    int address = 0, value = 0;
    
    if (data[0] == 4) {
        active = false;
    }
    
    for (int pos = 4; pos > 1; pos--) {
        address <<= 8;
        address |= (data[pos] & 0xFF);
    }
    
    value = (data[1] & 0xFF);
    
    for (int pos = 8; pos < 26; pos++) {
        if (data[pos] == 0) {
            break;
        }
        
        name += data[pos];
    }

    return CHTCode(name, address, value, active);
}

wxString CHTCode::toString() {
    wxString string;
    string.Alloc(50);
    
    string.Printf("%-18s %06X:%02X %-8s", getName().c_str(), getAddress(), 
                                         getValue(), 
                                         (isActive() ? "active" : "inactive"));
    
    return string;
}

